==> nextcloud-23.0.12p0.tgz: nextcloud/apps/password_policy/l10n/mk.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Лозинката е истечена, користете метод за заборавена лозинка за ресетирање",
    "Password must not have been used recently before." : "Лозинката не смее да биде веќе користена.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Лозинката е една од 1.000.000 лозинки кој најчесто се употербуваат. Ве молиме изберете уникатна лозинка.",
    "Password is present in compromised password list. Please choose a different password." : "Лозинката е присутна во компромирана листа со лозинки. Ве молиме изберете друга лозинка.",
    "Password needs to be at least %s characters long." : "Лозинката мора да биде најмалку со %s карактери.",
    "Password needs to contain at least one numeric character." : "Лозинката мора да содржи најмалку еден број.",
    "Password needs to contain at least one special character." : "Лозинката мора да содржи најмалку еден специјален карактер.",
    "Password needs to contain at least one lower and one upper case character." : "Лозинката мора да содржи најмалку една мала и голема буква.",
    "Password policy" : "Политика на лозинки",
    "Allows admins to configure a password policy" : "Дозволи им на администраторите да ја конфигурираат политиката на лозинки",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Дозволи им на адмистраторите да дефинираат услови за избор на лозинки, на пр. минимална должина на лозинка",
    "Saved" : "Зачувано",
    "Minimum password length" : "Минимална должина на лозинка",
    "User password history" : "Историја на лозинки за корисник",
    "Number of days until user password expires" : "Број на денови до истекување на лозинка на корисник",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Број на обиди за најава пред да се блокира корисничката сметка. (0 без ограничување)",
    "Forbid common passwords" : "Забранети обични лозинки",
    "Enforce upper and lower case characters" : "Задолжителни карактери со големи и мали букви",
    "Enforce numeric characters" : "Задолжителни карактери со броеви",
    "Enforce special characters" : "Задолжителни специјални карактери",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Проверка на лозинките дали се на компромирана листа на haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Оваа проверка создава хаш на лозинката и ги испраќа првите 5 карактери на овој хаш на hasibeenpwned.com преку API за да се добие список на сите хашови кои започнуваат со тие карактери. Потоа, Nextcloud серверот ја проверува листата на хашови со хашот на лозинката.",
    "Unknown error" : "Непозната грешка",
    "Minimal length has to be a non negative number" : "Минималната должина неможе да биде негативен број"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-29.0.10.tgz: nextcloud/apps/password_policy/l10n/mk.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Лозинката е истечена, користете метод за заборавена лозинка за ресетирање",
    "Password must not have been used recently before." : "Лозинката не смее да биде веќе користена.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Лозинката е една од 1.000.000 лозинки кој најчесто се употербуваат. Ве молиме изберете уникатна лозинка.",
    "Password is present in compromised password list. Please choose a different password." : "Лозинката е присутна во компромирана листа со лозинки. Ве молиме изберете друга лозинка.",
    "Password needs to be at least %s characters long." : "Лозинката мора да биде најмалку со %s карактери.",
    "Password needs to contain at least one numeric character." : "Лозинката мора да содржи најмалку еден број.",
    "Password needs to contain at least one special character." : "Лозинката мора да содржи најмалку еден специјален карактер.",
    "Password needs to contain at least one lower and one upper case character." : "Лозинката мора да содржи најмалку една мала и голема буква.",
    "Password policy" : "Политика на лозинки",
    "Allows admins to configure a password policy" : "Дозволи им на администраторите да ја конфигурираат политиката на лозинки",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Дозволи им на адмистраторите да дефинираат услови за избор на лозинки, на пр. минимална должина на лозинка",
    "Minimum password length" : "Минимална должина на лозинка",
    "User password history" : "Историја на лозинки за корисник",
    "Number of days until user password expires" : "Број на денови до истекување на лозинка на корисник",
    "Forbid common passwords" : "Забранети обични лозинки",
    "Enforce upper and lower case characters" : "Задолжителни карактери со големи и мали букви",
    "Enforce numeric characters" : "Задолжителни карактери со броеви",
    "Enforce special characters" : "Задолжителни специјални карактери",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Проверка на лозинките дали се на компромирана листа на haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Оваа проверка создава хаш на лозинката и ги испраќа првите 5 карактери на овој хаш на hasibeenpwned.com преку API за да се добие список на сите хашови кои започнуваат со тие карактери. Потоа, Nextcloud серверот ја проверува листата на хашови со хашот на лозинката.",
    "Unknown error" : "Непозната грешка",
    "Minimal length has to be a non negative number" : "Минималната должина неможе да биде негативен број",
    "History size has to be a non negative number" : "Историската должина неможе да биде негативен број",
    "Expiration days have to be a non negative number" : "Датумот на истекување неможе да биде негативен број",
    "Maximum login attempts have to be a non negative number" : "Максималниот број на обиди неможе да биде негативен број",
    "Settings saved" : "Параматрите се зачувани"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
